@@ -5,7 +5,8 @@
 #define WINPR_KEYMAP_PATH ""
 #define WINPR_PLUGIN_PATH ""
 
-#define WINPR_INSTALL_PREFIX ""
+#define WINPR_INSTALL_PREFIX "/usr"
+#define WINPR_INSTALL_SYSCONFDIR "/etc"
 
 #define WINPR_LIBRARY_PATH ""
 
@@ -19,4 +20,6 @@
 
 #define WINPR_PROXY_PLUGINDIR ""
 
+/* #undef WINPR_USE_VENDOR_PRODUCT_CONFIG_DIR */
+
 #endif /* WINPR_BUILD_CONFIG_H */
